@@ -2,6 +2,8 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+import logging
+
 from django.contrib.auth.models import User
 from django.contrib.sites.models import Site
 from django.db import models
@@ -14,8 +16,9 @@ from reviewboard.site.urlresolvers import local_site_reverse
 
 from rbbz.bugzilla import Bugzilla
 from rbbz.diffs import build_plaintext_review
-from rbbz.errors import (BugzillaError, ConfidentialBugError, InvalidBugsError,
-                         InvalidBugIdError)
+from rbbz.errors import (BugzillaError, ConfidentialBugError, InvalidBugIdError)
+
+BZIMPORT_PREFIX = "bz://"
 
 def review_request_url(review_request, site=None, siteconfig=None):
     if not site:
@@ -57,6 +60,9 @@ def publish_review_request(user, review_request_draft, **kwargs):
     # the bug ID.
     bug_id = review_request_draft.extra_data.get('p2rb.identifier', None)
 
+    if bug_id.startswith(BZIMPORT_PREFIX):
+      bug_id = bug_id[len(BZIMPORT_PREFIX):]
+
     try:
         bug_id = int(bug_id)
     except (TypeError, ValueError):
@@ -67,10 +73,11 @@ def publish_review_request(user, review_request_draft, **kwargs):
     try:
         if b.is_bug_confidential(bug_id):
             raise ConfidentialBugError
-    except xmlrpclib.Fault as e:
-        # 100: Invalid Bug Alias
-        # 101: Bug does not exist
-        if e.faultCode == 100 or e.faultCode == 101:
+    except BugzillaError as e:
+        # Special cases:
+        #   100: Invalid Bug Alias
+        #   101: Bug does not exist
+        if e.fault_code and (e.fault_code == 100 or e.fault_code == 101):
             raise InvalidBugIdError(bug_id)
         raise
 
@@ -91,6 +98,15 @@ def publish_review_request(user, review_request_draft, **kwargs):
                       review_request_draft.description,
                       review_request_url(review_request),
                       reviewers)
+        # Publish and child review requests that are either not
+        # public, or have drafts.
+        for child in review_request_draft.depends_on.all():
+            if child.get_draft(user=user) or not child.public:
+                try:
+                    child.publish(user=user)
+                except PermissionError as e:
+                    logging.error('Could not publish child review request '
+                                  'with id %s because of error %s' % (child.id, e))
 
 def publish_review(user, review, **kwargs):
     review_request = review.review_request
